@@ -1,10 +1,10 @@
-#!/usr/bin/env python
-
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
 
 # Standard library imports
-import os
+from __future__ import annotations
+
+from pathlib import Path
 
 
 def create_npmrc():
@@ -12,8 +12,8 @@ def create_npmrc():
     Create NPM configuration file in user home directory to use authentication
     token from environment variables.
     """
-    fpath = os.path.expanduser("~/.npmrc")
-    with open(fpath, "w") as fh:
+    fpath = Path("~/.npmrc").expanduser()
+    with fpath.open("w") as fh:
         fh.write("//registry.npmjs.org/:_authToken=${NPM_TOKEN}")
 
 
